Metadata class

Represents the metadata for a radio stream.

Constructors

Metadata({required String? artist, required String? title, String? artworkUrl, Uint8List? artworkData})
Metadata.fromMap(Map map)
factory

Properties

artist → String?
final
artworkData → Uint8List?
final
artworkUrl → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited