builder property
A builder function that receives the visualizer data and returns a widget. The data is a list of integers representing frequency bands (0-255).
Implementation
final Widget Function(BuildContext context, List<int> data) builder;
A builder function that receives the visualizer data and returns a widget. The data is a list of integers representing frequency bands (0-255).
final Widget Function(BuildContext context, List<int> data) builder;